Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/edwh_auth_rbac/__init__.py | (no class) | 3 | 0 | 0 | 100%
src/edwh_auth_rbac/helpers.py | (no class) | 1 | 0 | 0 | 100%
src/edwh_auth_rbac/migrations.py | (no class) | 3 | 0 | 0 | 100%
src/edwh_auth_rbac/model.py | DEFAULT | 0 | 0 | 0 | 100%
src/edwh_auth_rbac/model.py | Password | 9 | 2 | 0 | 78%
src/edwh_auth_rbac/model.py | (no class) | 42 | 0 | 0 | 100%
src/edwh_auth_rbac/rbac.py | AuthRbac | 63 | 39 | 0 | 38%
src/edwh_auth_rbac/rbac.py | (no class) | 25 | 0 | 0 | 100%
tests/__init__.py | (no class) | 0 | 0 | 0 | 100%
tests/test_rbac.py | database.Database | 5 | 0 | 0 | 100%
tests/test_rbac.py | TestSequentially | 57 | 2 | 0 | 96%
tests/test_rbac.py | (no class) | 33 | 0 | 0 | 100%
Total |  | 241 | 43 | 0 | 82%

No items found using the specified filter.